:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _changelog:

Changelog
=========

2.11.2 (not yet released)
-------------------------

2.11.1 (January 27th 2018)
--------------------------

* First release of Grappelli which is compatible with Django 2.0.
